@@ -7,9 +7,10 @@
 /*
    Copyright (C) 2003 Red Hat, Inc. All rights reserved.
                                                                                                              
-   Usage and distribution of this file are subject to the Open Software License version 1.1
-   that can be found at http://www.opensource.org/licenses/osl-1.1.txt and the COPYING file as
-   distributed together with this file is included herein by reference.
+   Usage and distribution of this file are subject to the Open Software License version 2.1
+   that can be found at http://www.opensource.org/licenses/osl-2.1.txt and the COPYING file as
+   distributed together with this file is included herein by reference. Alternatively you can use 
+   and distribute this file under version 1.1 of the same license.
                                                                                                                       
    Author: Arjan van de Ven   <arjanv@redhat.com>
 
@@ -55,6 +56,7 @@ char *storage_modules[] = {
 	"oic",
 	"libata",
 	"ohci1394",
+	"sym53c8xx",
 	0
 };
 
