@@ -2,16 +2,18 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
+#include <signal.h>
 
 /*
    Copyright (C) 2003 Red Hat, Inc. All rights reserved.
                                                                                                              
-   Usage and distribution of this file are subject to the Open Software License version 1.1
-   that can be found at http://www.opensource.org/licenses/osl-1.1.txt and the COPYING file as
-   distributed together with this file is included herein by reference.
+   Usage and distribution of this file are subject to the Open Software License version 2.1
+   that can be found at http://www.opensource.org/licenses/osl-2.1.txt and the COPYING file as
+   distributed together with this file is included herein by reference. Alternatively you can use 
+   and distribute this file under version 1.1 of the same license.
                                                                                                                       
-   Author: Arjan van de Ven   <arjanv@redhat.com>
-
+   Authors: Arjan van de Ven   <arjanv@redhat.com>
+            Eric Dorland       <eric@debian.org>
 */
 
 #include "prototypes.h"
@@ -24,6 +26,11 @@ struct irqdescriptor interrupts[MAX_INTERRUPTS];
 
 int rotate_premium = 12500;
 
+void term_signal(int signal)
+{
+    unlink("/var/run/irqbalance.pid");
+    exit(EXIT_SUCCESS);
+}
 
 void commandpolicy(char *pol, int phase)
 {
@@ -44,7 +51,8 @@ void commandpolicy(char *pol, int phase)
 
 int main(int argc, char **argv)
 {
-	int oneshot = 0;
+    FILE *pid_file;
+    int oneshot = 0;
 	
 	class_policy[IRQ_TIMER] = POLICY_ROTATE;
 	
@@ -65,8 +73,15 @@ int main(int argc, char **argv)
 		exit(EXIT_SUCCESS);
 	parse_proc_interrupts(0); 
 
-#ifndef DEBUG	
-	daemon(0,0);
+#ifndef DEBUG
+	pid_file = fopen("/var/run/irqbalance.pid", "w");
+	if (pid_file == NULL)
+        exit(EXIT_FAILURE);
+    daemon(0,0);
+    signal(SIGTERM, term_signal);
+    fprintf(pid_file, "%d\n", getpid());
+    fclose(pid_file);
+    
 #endif
 	/* 
 	 * Allow 5 seconds for gathering irq counts before the first balance; 60 in case of one-shot
